import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/auth/bloc/auth_bloc.dart';
import 'package:syncrow_web/pages/auth/view/login_page.dart';
import 'package:syncrow_web/pages/home/bloc/home_bloc.dart';
import 'package:syncrow_web/pages/home/view/home_page.dart';
import 'package:syncrow_web/pages/visitor_password/bloc/visitor_password_bloc.dart';
import 'package:syncrow_web/services/locator.dart';
import 'package:syncrow_web/utils/color_manager.dart';

Future<void> main() async {
  WidgetsFlutterBinding.ensureInitialized();
  initialSetup(); // Perform initial setup, e.g., dependency injection
  String checkToken = await AuthBloc.getTokenAndValidate();
  runApp(MyApp(
    isLoggedIn: checkToken,
  ));
}

class MyApp extends StatelessWidget {
  final dynamic isLoggedIn;
  const MyApp({
    super.key,
    required this.isLoggedIn,
  });
  @override
  Widget build(BuildContext context) {
    return MultiBlocProvider(
        providers: [
          BlocProvider(create: (context) => HomeBloc()),
          BlocProvider<VisitorPasswordBloc>(
            create: (context) => VisitorPasswordBloc(),
          )
        ],
        child: MaterialApp(
          debugShowCheckedModeBanner: false, // Hide debug banner
          scrollBehavior: const MaterialScrollBehavior().copyWith(
            dragDevices: {
              PointerDeviceKind.mouse,
              PointerDeviceKind.touch,
              PointerDeviceKind.stylus,
              PointerDeviceKind.unknown,
            },
          ),

          theme: ThemeData(
            fontFamily: 'Aftika',
            textTheme: const TextTheme(
              bodySmall: TextStyle(
                  fontSize: 13,
                  color: ColorsManager.whiteColors,
                  fontWeight: FontWeight.bold),
              bodyMedium: TextStyle(color: Colors.black87, fontSize: 14),
              bodyLarge: TextStyle(fontSize: 16, color: Colors.white),
              headlineSmall: TextStyle(color: Colors.black87, fontSize: 18),
              headlineMedium: TextStyle(color: Colors.black87, fontSize: 20),
              headlineLarge: TextStyle(
                color: Colors.white,
                fontSize: 24,
                fontWeight: FontWeight.bold,
              ),
            ),
            colorScheme: ColorScheme.fromSeed(
              seedColor: ColorsManager.blueColor,
              primary: ColorsManager.blueColor, // Checked state color
              onSurface: Colors.grey.shade400, // Unchecked state color
            ),
            switchTheme: SwitchThemeData(
              thumbColor: MaterialStateProperty.resolveWith((states) {
                if (states.contains(MaterialState.selected)) {
                  return ColorsManager
                      .blueColor; // Color of the switch knob when selected
                }
                return ColorsManager
                    .whiteColors; // Color of the switch knob when not selected
              }),
              trackColor: MaterialStateProperty.resolveWith((states) {
                if (states.contains(MaterialState.selected)) {
                  return ColorsManager.blueColor
                      .withOpacity(0.5); // Track color when selected
                }
                return ColorsManager
                    .whiteColors; // Track color when not selected
              }),
            ),
            checkboxTheme: CheckboxThemeData(
              fillColor: MaterialStateProperty.resolveWith((states) {
                if (states.contains(MaterialState.selected)) {
                  return ColorsManager.blueColor; // Checked state color
                }
                return Colors.grey.shade200; // Unchecked state color
              }),
              checkColor: MaterialStateProperty.all(
                  Colors.white), // The color of the checkmark
              side:
                  BorderSide(color: ColorsManager.whiteColors), // Border color
              shape: RoundedRectangleBorder(
                borderRadius: BorderRadius.circular(4), // Border radius
              ),
            ),
            useMaterial3: true, // Enable Material 3
          ),
          home: isLoggedIn == 'Success' ? const HomePage() : const LoginPage(),
        ));
  }
}
